==> asn.1_4.5.tar.gz: asn.1-4.5/package.lisp <==
;;;; -*- Mode: Lisp; Package: ASN.1; -*-

(in-package :cl-user)

(defpackage asn.1
  (:use #+genera :future-common-lisp
        #-genera :common-lisp
        #+lispworks :harlequin-common-lisp
        #+lispworks :lispworks
        #+lispworks :parsergen
        :trivial-gray-streams)
  (:export #:ber-decode
	   #:ber-decode<-string
           #:ber-decode-value
           #:ber-encode
	   #:ber-encode->string
           #:ber-encode-length
	   #:ber-encode-list
           #:ber-encode-type
           #:ber-equal
           #:ber-stream
           #:compile-asn.1
           #:counter
           #:counter32
           #:counter64
           #:defunknown
           #:defoid
           #:delete-object
           #:gauge
           #:get-asn.1-type
           #:install-asn.1-type
           #:integer
           #:ipaddress
           #:load-asn.1
           #:mibrowser
           #:object-id
           #:oid
           #:oid-leaf-p
           #:oid-length
           #:oid-name
           #:oid-name-list
           #:oid-next
           #:oid-walk
           #:oid-number-list
           #:oid-parent
           #:oid-parent-p
           #:oid-scalar-variable-p
           #:oid-trunk-p
           #:oid-value
	   #:oid-<
	   #:oid->=
           #:opaque
           #:plain-value
           #:raw
           #:string
           #:timeticks
           #:uninstall-asn.1-type))

(in-package :asn.1)

;;; Logical Pathname Translations, learn from CL-HTTP source code
(eval-when (:load-toplevel :execute)
  (let* ((defaults #+asdf (asdf:component-pathname (asdf:find-system :asn.1))
                   #-asdf *load-pathname*)
         (home (make-pathname :name :wild :type :wild
                              :directory (append (pathname-directory defaults)
                                                 '(:wild-inferiors))
                              :host (pathname-host defaults)
                              :defaults defaults
			      :version :newest)))
    (setf (logical-pathname-translations "ASN")
          `(("**;*.*.NEWEST" ,home)
	    ("**;*.*" ,home)))))

(defparameter *version* 4.5)

==> asn.1_4.12.tar.gz: asn.1-4.12/package.lisp <==
;;;; -*- Mode: Lisp -*-
;;;; $Id: package.lisp 576 2008-10-20 16:10:54Z binghe $

(in-package :cl-user)

(defpackage asn.1
  (:use #+genera :future-common-lisp
        #-genera :common-lisp
        #+lispworks :parsergen
        #-scl :trivial-gray-streams)
  (:export #:ber-decode
	   #:ber-decode<-string
           #:ber-decode-value
           #:ber-encode
	   #:ber-encode->string
           #:ber-encode-length
	   #:ber-encode-list
           #:ber-encode-type
           #:ber-equal
           #:ber-stream
           #:compile-asn.1
           #:counter
           #:counter32
           #:counter64
           #:defunknown
           #:defoid
           #:delete-object
           #:gauge
           #:get-asn.1-type
           #:install-asn.1-type
           #:integer
           #:ipaddress
           #:load-asn.1
           #:mibrowser
           #:object-id
           #:oid
           #:oid-find-leaf
           #:oid-leaf-p
           #:oid-length
           #:oid-name
           #:oid-name-list
           #:oid-next
           #:oid-walk
           #:oid-number-list
           #:oid-parent
           #:oid-parent-p
           #:oid-scalar-variable-p
           #:oid-trunk-p
           #:oid-value
	   #:oid-<
	   #:oid->=
           #:opaque
           #:plain-value
           #:raw
           #:string
           #:timeticks
           #:uninstall-asn.1-type))

(in-package :asn.1)

;;; Logical Pathname Translations, learn from CL-HTTP source code
(eval-when (:load-toplevel :execute)
  (let* ((defaults #+asdf (asdf:component-pathname (asdf:find-system :asn.1))
                   #-asdf *load-pathname*)
         (home (make-pathname :name :wild :type :wild
                              :directory (append (pathname-directory defaults)
                                                 '(:wild-inferiors))
                              :host (pathname-host defaults)
                              :defaults defaults
			      :version :newest)))
    (setf (logical-pathname-translations "ASN")
          `(("**;*.*.NEWEST" ,home)
	    ("**;*.*" ,home)))))

(defvar *major-version* 4)
(defvar *minor-version* 12)
